proc styles_active {status} {
   set wl [list .mf.bjcp .c.ogrange .c.fgmin .c.fgmax .c.srmrange .c.iburange]
   lappend wl .c.stq
   foreach w $wl { $w configure -state $status }
}

proc sethop {idx} {
   global Hop hops
   set hopname $Hop($idx:variety)
   set aa $hops($hopname)
   set Hop($idx:aa) $aa
}


# In check_bjcp, we need to test INT values to avoid showing a value in
# red when it's just off by a decimal amount (e.g., if the upper limit
# on OG is 1.050, don't indicate an error for a value of 1.0501).

proc getpts {sg} { return [expr {(1.000*$sg - 1)*1000}] }
proc intval {c} { return [expr {int($c)}] }

proc check_bjcp {} {
   global OGSG ogmin ogmax fgmin fgmax totalibus
   global dSRM srmmin srmmax bjcp ibumin ibumax

   set testog [getpts $OGSG]
   set testmax [getpts $ogmax]
   set testmin [getpts $ogmin]

   if {!$bjcp} { return }
   if {$testog >= $testmin && $OGSG <= $testmax} {
      .c.ogrange configure -foreground #00cc00
   } else {
      .c.ogrange configure -foreground red
   }

   set tsrm [intval $dSRM]
   set minsrm [intval $srmmin]
   set maxsrm [intval $srmmax]

   if {$tsrm >= $minsrm && $tsrm <= $maxsrm} {
      .c.srmrange configure -foreground #00cc00
   } else {
      .c.srmrange configure -foreground red
   }
   set tibus [expr {int($totalibus * 10.00)/10.0}]
   set totalibus $tibus
   set minibu [expr {int($ibumin   * 10.00)/10.0}]
   set maxibu [expr {int($ibumax   * 10.00)/10.0}]

   if {$tibus >= $minibu && $tibus <= $maxibu} {
      .c.iburange configure -foreground #00cc00
   } else {
      .c.iburange configure -foreground red
   }

}


# Simple proc for quick one-line entries (e.g., Name:____)
proc oneval {x y var {width 20}} {
   global small_text relief
   entry .c.e$x:$y -textvariable $var -relief $relief -background white \
      -foreground black -font $small_text -width $width
   .c create window $x $y -window .c.e$x:$y -anchor w
   return .c.e$x:$y
}


# Same...but for the hop data
proc onehop {x y var {width 20}} {
   global labels relief small_text

   entry .c.e$x:$y -textvariable $var -relief $relief -background white \
      -foreground black -font $labels -width $width -font $small_text
   .c create window $x $y -window .c.e$x:$y -anchor w
   return .c.e$x:$y
}


# Simple proc for quick one-line feedback (e.g., %IBU:____)
proc onelbl {x y var {width 20}} {
   global small_text relief small_text
   label .c.l$x:$y -textvariable $var -relief $relief -background white \
      -foreground black -font $small_text -borderwidth 0
   .c create window $x $y -window .c.l$x:$y -anchor w
}

proc onearlbl {x y var lbl} {
   global labels relief
   label .c.$lbl -textvariable $var -relief flat -background white \
      -foreground black -font $labels
   .c create window $x $y -window .c.$lbl -anchor w
}



# Place simple text on the page---no variables...just text
proc txt {s x y} {
   global plain_labels
   .c create text $x $y -text $s -anchor w -font $plain_labels -fill blue
}

# Place bold text on the page---no variables...just text
proc btxt {s x y} {
   global labels
   .c create text $x $y -text $s -anchor w -font $labels -fill blue
}

proc grainval {x y var {width 3}} {
   global small_labels relief
   entry .c.e$x:$y -textvariable $var -relief $relief -background white \
      -foreground black -font $small_labels -width $width
   .c create window $x $y -window .c.e$x:$y -anchor w
}


proc checkdilu {args} {
   global batchsize OGSG preboilvol preboilsg
   if {[streqx $batchsize "" 0]} { return }
   if {[streqx $OGSG "" 0]} { return }
   if {[streqx $preboilvol "" 0]} { return }
   if {[streqx $preboilsg "" 0]} { return }
   getvolsg
}

proc checkeff {args} {
   global ogactual finalvol totalweight endmasheff mashppg actualppg
   global newmasheff

   if {[streqx $ogactual "" 0]} { return }
   if {[streqx $finalvol "" 0]} { return }
   if {[streqx $totalweight "" 0]} { return }

   set newmasheff [masheff $ogactual $finalvol $totalweight]
   set endmasheff "Mash eff. (%) = $newmasheff"
   set actualppg [get_ppg $ogactual $finalvol $totalweight]
   set mashppg "Mash pts/lb/gal = $actualppg"
   update
}


proc checkogfg {} {
   global ogactual fgactual abv cals

   if {[streqx $ogactual "" 0]} { return }
   if {[streqx $fgactual "" 0]} { return }
   set abv "[get_abv] %v/v"
#  puts "ext cals:      [ext_calories]" ;# returns negative number
#  set cals "approx. [expr {round(1.000*[alc_calories]+[ext_calories])}] calories"
}


