
# Part of my Tcl lib, jdglib.
# package provide jdglib 1.0.5

proc streq {s1 s2} {
   return [expr {[string compare $s1 $s2] == 0}]
   return 0
}


# Compare multiple strings with s1 ... return number of matches
proc streqx {s1 args} {
   set ret 0
   foreach s $args {
      if {[streq $s1 $s]} { incr ret }
   }
   return $ret
}



# stripzeros:  strip leading zeros from numbers (e.g., 098 --> 98)

proc stripzeros {value} {
   set retval [string trimleft $value 0]
   if {![string length $retval]} { return 0 }
   return $retval
}



# Add commas to numbers (i.e., human formatting).  Could be nice and
# configure this to be more international, but this is my library...and
# unless I distribute it, it's not an issue.  :-)
proc numstr {n} {
   set neg 0 ; set isfloat 0
   if {$n < 0} { set neg 1 ; set n [expr {abs($n)}] }
   if {[regexp {^([0-9]*)\.([0-9]*)$} $n a int dec]} {
      set isfloat 1
      set n $int ;# can't use floating point below
   }

   set ret ""
   if {$n > 999} {
      set ret [format %03d [expr {$n%1000}]]
      set n [expr {int($n/1000)}]
      while {$n > 999} {
         set ret [format %03d [expr {$n%1000}]],$ret
         set n [expr {int($n/1000)}]
      }
      set ret $n,$ret
   } else {
      set ret $n
   }
   if {$neg} { set ret "-$ret" }
   if {$isfloat} { set ret "$ret.$dec" }
   return $ret
}


# From the Wiki:

# Tabs to spaces, and back: courtesy Jeffrey Hobbs

# untabify---removes tabs from a string, replacing with appropriate
# number of spaces. Arguments:
#      str    - input string
#      tablen - tab length, defaults to 8
# Returns:
#   string sans tabs
#
proc untabify {str {tablen 8}} {
   set out {}
   while {[set i [string first "\t" $str]] != -1} {
      set j [expr {$tablen-($i%$tablen)}]
      append out [string range $str 0 [incr i -1]][format %*s $j { }]
      set str [string range $str [incr i 2] end]
   }
   return $out$str
}
# tabify---converts excess spaces to tab chars. Arguments:
#      str    - input string
#      tablen - tab length, defaults to 8
# Returns:
#   string with tabs replacing excess space where appropriate
#
proc tabify {str {tablen 8}} {
   ## We must first untabify so that \t is not interpreted to be 1 char
   set str [untabify $str]
   set out {}
   while {[set i [string first { } $str]] != -1} {
      ## Align i to the upper tablen boundary
      set i [expr {$i+$tablen-($i%$tablen)-1}]
      set s [string range $str 0 $i]
      if {[string match {* } $s]} {
         append out [string trimright $s { }]\t
      } else {
         append out $s
      }
      set str [string range $str [incr i] end]
   }
   return $out$str
}



