package require autoscroll

proc readstyle {} {
   global snum Style styles dataview

   set styledir data/styleguides

   regsub -all {/} $Style {-} rstyle

   if {[regexp {^([0-9]+)([A-Z]).*} $rstyle a idxnum idxltr]} {
      if {$idxnum > 9} { set fdir [glob $styledir/${idxnum}*]
      } else {           set fdir [glob $styledir/0${idxnum}*]
      }
      set fn [glob $fdir/$idxnum${idxltr}*]
   } elseif {$snum == 20} {
      set fn data/styleguides/20._Fruit_Beer/20._Fruit_Beer
   } elseif {$snum == 23} {
      set fn data/styleguides/23._Specialty_Beer/23._Specialty_Beer
   } else {
      puts "regexp failed..."
      return
   }
   catch { toplevel .bjcp }
   wm geometry .bjcp +274+47

   pack [frame .bjcp.style -background white] -side top
   set w .bjcp.style

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .bjcp.done -text "Dismiss" -command { destroy .bjcp } \
      -background black -foreground #00FFFF
   pack .bjcp.done -side top -expand n

   set f [open $fn r]


   set flist [split [read $f] \n]
   close $f
   set i 0
   foreach line $flist {
      if {$i == 0} {
         regsub -all {_} $line { } foo
         regsub -all -- {-} $foo {/} line
         incr i
      }
      .bjcp.style.t insert end $line\n
   }
}


proc get_yeast_info {} {
   global dataview topdir
   cd $topdir
   set fn [tk_getOpenFile -title "Select yeast" -initialdir data/YEAST]
   if {$fn == ""} { return }

   catch { toplevel .yeastdata }
   wm geometry .yeastdata +274+47

   pack [frame .yeastdata.top -background white] -side top
   set w .yeastdata.top

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .yeastdata.done -text "Dismiss" -command { destroy .yeastdata } \
      -background black -foreground #00FFFF
   pack .yeastdata.done -side top -expand n

   set f [open $fn r]


   set flist [split [read $f] \n]
   close $f
   foreach line $flist {
      .yeastdata.top.t insert end $line\n
   }
}


proc get_grain_info {} {
   global dataview topdir
   cd $topdir
   set fn [tk_getOpenFile -title "Select grain category" -initialdir data/Malt]
   if {$fn == ""} { return }

   catch { toplevel .graindata }
   wm geometry .graindata +274+47

   pack [frame .graindata.top -background white] -side top
   set w .graindata.top

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .graindata.done -text "Dismiss" -command { destroy .graindata } \
      -background black -foreground #00FFFF
   pack .graindata.done -side top -expand n

   set f [open $fn r]


   set flist [split [read $f] \n]
   close $f
   foreach line $flist {
      .graindata.top.t insert end $line\n
   }
}


proc get_bjcp_info {} {
   global dataview topdir
   cd $topdir
   set fn [tk_getOpenFile -title "Select BJCP Style" \
      -initialdir data/styleguides]
   if {$fn == ""} { return }

   catch { toplevel .bjcpdata }
   wm geometry .bjcpdata +274+47

   pack [frame .bjcpdata.top -background white] -side top
   set w .bjcpdata.top

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .bjcpdata.done -text "Dismiss" -command { destroy .bjcpdata } \
      -background black -foreground #00FFFF
   pack .bjcpdata.done -side top -expand n

   set f [open $fn r]


   set flist [split [read $f] \n]
   close $f
   foreach line $flist {
      .bjcpdata.top.t insert end $line\n
   }
}


proc get_hop_info {} {
   global dataview topdir
   cd $topdir
   set fn [tk_getOpenFile -title "Select hop variety" -initialdir data/Hops]
   if {$fn == ""} { return }

   catch { toplevel .hopdata }
   wm geometry .hopdata +274+47

   pack [frame .hopdata.top -background white] -side top
   set w .hopdata.top

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .hopdata.done -text "Dismiss" -command { destroy .hopdata } \
      -background black -foreground #00FFFF
   pack .hopdata.done -side top -expand n

   set f [open $fn r]


   set flist [split [read $f] \n]
   close $f
   foreach line $flist {
      .hopdata.top.t insert end $line\n
   }
}


# Returns CO2 pressure for $vol volumes of CO2 at $tempF deg F

proc CO2_pressure {vol tempF} {  
   return [expr {-16.6999 - (0.0101059 * $tempF) \
      + (0.00116512 * $tempF * $tempF) + (0.173354 * $tempF * $vol) \
      + (4.24267 * $vol) - (0.0684226 * $vol * $vol)}]
}



proc get_co2_info {} {
   global dataview

   catch { toplevel .co2data }
   wm geometry .co2data +274+47

   pack [frame .co2data.top -background white] -side top
   set w .co2data.top

   text $w.t -yscrollcommand "$w.scrolly set" -font $dataview \
   -background black -foreground #00FFFF
   pack $w.t -side top
   scrollbar $w.scrolly -orient v -command "$w.t yview"
   pack $w.scrolly -side right -fill y
   pack $w.t -side left -fill both -expand 1
   ::autoscroll::autoscroll $w.scrolly
#  pack $w.t

   button .co2data.done -text "Dismiss" -command { destroy .co2data } \
      -background black -foreground #00FFFF
   pack .co2data.done -side top -expand n


   set w .co2data.top.t

   label $w.l1 -text "Desired CO2 volumes:  " -font $dataview \
      -background black -foreground #00FFFF -relief flat
   entry $w.e1 -width 5 -font $dataview -textvariable volumes
   $w window create end -window $w.l1
   $w window create end -window $w.e1
   $w insert end "\n"

   label $w.l2 -text "Temperature (deg. F):  " -font $dataview \
      -background black -foreground #00FFFF -relief flat
   entry $w.e2 -width 5 -font $dataview -textvariable carbtemp
   $w window create end -window $w.l2
   $w window create end -window $w.e2
   $w insert end "\n"

   set carbpsi ""
   button $w.calc -text {[Calc]} -font $dataview \
      -command { set carbpsi [CO2_pressure $volumes $carbtemp] } \
      -background black -foreground #00FFFF -relief flat
   label $w.result -font $dataview -textvariable carbpsi
   $w window create end -window $w.calc
   $w window create end -window $w.result
   $w insert end "\n"
   $w insert end "\n"

   $w insert end "Some typical carbonation levels:

   British-style ales:      1.5 - 2.0
   Porter, stout:           1.7 - 2.3
   Belgian ales:            1.9 - 2.4
   European lagers:         2.2 - 2.7
   American ales & lagers:  2.2 - 2.7
   Lambic:                  2.4 - 2.8
   Fruit lambic:            3.0 - 4.5
   German wheat beer:       3.3 - 4.5

NOTE:  it may take several days to a week to reach these levels using
head-pressure alone.  To reduce this by roughly half, switch your gas
in connector with the liquid out connector, and inject CO2 from the
bottom of the keg.  According to one site, this should take roughly
48 hours.
"
}






